Editor support
==============

There are some plugins for the major open source editors ``vim`` and ``emacs``.

1 VIM
-----

There is a new well-maintained and high-quality package for neovim
`papis.nvim <https://github.com/jghauser/papis.nvim>`__.

If neovim is a deal breaker for you, you can take a look at the
original ``vim`` plugin `papis-vim <https://github.com/papis/papis-vim>`__.

2 Emacs
-------

`papis.el <https://github.com/papis/papis.el>`__ is a compatibility layer for
Papis that tries to use as much of the existing packages as possible.
In particular it tries to make use also of ``org-ref``
to try not to reinvent the wheel.
If you are used to ``org-ref`` or ``org-cite`` it strives
to work seamless with them and still have your Papis
library intact.
